import {
    Button,
    Dialog,
    DialogContent,
    DialogTitle,
    Stack,
    TextField,
} from '@mui/material'
import { useFormik } from 'formik'
import { Fragment, FunctionComponent, useEffect, useState } from 'react'
import SendIcon from '@mui/icons-material/Send'
import ClearIcon from '@mui/icons-material/Clear'
import { PathDto } from '../../swagger/data-contracts'
import axiosInstance from '../../api/api'
import { useDispatch, useSelector } from 'react-redux'
import { showNotification } from '../Notification/notificationSlice'
import { RootState } from '../redux/store'
import { sendTextForProcessing } from './trackingToolThunks'
import * as yup from 'yup'
import { resetDialogApiCallSuccess } from './trackingToolSlice'

const PlaintextUpload = () => {
    const loading = useSelector(
        (state: RootState) => state.trackingTool.isLoading
    )
    const [open, setOpen] = useState(false) // controls whether the dialog is open

    // This controls whether to keep dialog open after sending the request to the API
    const dialogApiCallSuccess = useSelector(
        (state: RootState) => state.trackingTool.dialogApiCallSuccess
    )

    const dispatch = useDispatch()

    const validationSchema = yup.object().shape({
        text: yup.mixed().required('Text is required'),
    })

    const formik = useFormik({
        initialValues: {
            text: '',
        },
        validationSchema,
        onSubmit: async () => {
            // Dispatch the thunk
            dispatch(sendTextForProcessing(formik.values.text))
        },
    })

    const onCloseDialog = () => {
        formik.resetForm()
        setOpen(false)
    }

    const resetForm = () => {
        formik.resetForm()
    }

    useEffect(() => {
        if (!dialogApiCallSuccess) {
            return
        }
        dispatch(resetDialogApiCallSuccess())
        setOpen(false)
    }, [dialogApiCallSuccess, dispatch])

    return (
        <Fragment>
            <Button variant="contained" onClick={() => setOpen(true)}>
                Text
            </Button>
            <Dialog
                open={open}
                fullWidth={true}
                onClose={onCloseDialog}
                maxWidth="lg"
            >
                <DialogTitle>Plaintext Input</DialogTitle>
                <DialogContent>
                    <form onSubmit={formik.handleSubmit}>
                        <TextField
                            sx={{ my: 2 }}
                            fullWidth
                            multiline
                            label="Plaintext input"
                            rows={10}
                            name="text"
                            value={formik.values.text}
                            onChange={formik.handleChange}
                        />
                        <Stack
                            alignItems="flex-end"
                            justifyContent="flex-end"
                            spacing={2}
                            direction="row"
                        >
                            <Button
                                variant="contained"
                                color="secondary"
                                onClick={resetForm}
                                startIcon={<ClearIcon />}
                            >
                                Clear
                            </Button>
                            <Button
                                type="submit"
                                variant="contained"
                                startIcon={<SendIcon />}
                                disabled={loading}
                            >
                                Submit
                            </Button>
                        </Stack>
                    </form>
                </DialogContent>
            </Dialog>
        </Fragment>
    )
}

export default PlaintextUpload
